@@ -32,7 +32,7 @@ from typing import List, Union
 
 import discord
 from discord.ext.commands import AutoShardedBot, Bot, Context
-from dislash import ActionRow, MessageInteraction, ResponseType, SlashClient
+from dislash import ActionRow, ButtonStyle, MessageInteraction, ResponseType, SlashClient
 
 from .abc import _PageController
 from .buttons import ComponentsButton
@@ -123,6 +123,9 @@ class ButtonsMenu:
         self._menu_timed_out = False
         self._main_page_contents = collections.deque()
         self._last_page_contents = collections.deque()
+        self._relay_function: 'function' = None
+
+        self._bypass_primed = False # used in :meth:`update()`
 
         # kwargs
         self.wrap_in_codeblock: Union[str, None] = options.get('wrap_in_codeblock')
@@ -346,9 +349,11 @@ class ButtonsMenu:
                     # before we continue, check if there are any duplicate named channels/no matching names found if a str was provided
                     if isinstance(send_to, str):
                         matched_channels = [ch for ch in self._ctx.guild.text_channels if ch.name == send_to]
-                        NO_CHANNELS_ERROR = f'When using parameter "send_to" in ButtonsMenu.start(), there were no channels with the name {send_to!r}'
-                        MULTIPLE_CHANNELS_ERROR = f'When using parameter "send_to" in ButtonsMenu.start(), there were {len(matched_channels)} channels with the name {send_to!r}. With multiple channels having the same name, the intended channel is unknown'  
-                        raise ButtonsMenuException(NO_CHANNELS_ERROR if len(matched_channels) == 0 else MULTIPLE_CHANNELS_ERROR)
+                        if len(matched_channels) == 0:
+                            raise ButtonsMenuException(f'When using parameter "send_to" in ButtonsMenu.start(), there were no channels with the name {send_to!r}')
+                        
+                        elif len(matched_channels) >= 2:
+                            raise ButtonsMenuException(f'When using parameter "send_to" in ButtonsMenu.start(), there were {len(matched_channels)} channels with the name {send_to!r}. With multiple channels having the same name, the intended channel is unknown')
                     
                     for channel in self._ctx.guild.text_channels:
                         if isinstance(send_to, str):
@@ -474,8 +479,31 @@ class ButtonsMenu:
         
         return kwargs
 
+    async def _handle_event(self, button: ComponentsButton):
+        """If an event is set, disable/remove the buttons from the menu when the click requirement has been met
+
+            .. added:: v2.0.2
+        """
+        if button.event:
+            event_type = button.event.event_type
+            event_value = button.event.value
+            if button.total_clicks == event_value:
+                if event_type == ComponentsButton.Event._disable:
+                    self.disable_button(button)
+                    await self.refresh_menu_buttons()
+                
+                elif event_type == ComponentsButton.Event._remove:
+                    self.remove_button(button)
+                    await self.refresh_menu_buttons()
+    
     async def _execute_interactive_session(self):
-        """|coro| Handles all processing of the pagination session"""
+        """|coro| Handles all processing of the pagination session
+        
+            .. changes::
+                v2.0.1
+                    Added handling for `ComponentsButton.ID_CUSTOM_EMBED`
+                    Added handling for relays
+        """
         ButtonsMenu._active_sessions.append(self)
         while self._is_running:
             try:
@@ -493,20 +521,26 @@ class ButtonsMenu:
                     cmp_btn._ComponentsButton__clicked_by.add(inter.author)
                     cmp_btn._ComponentsButton__total_clicks += 1
                     cmp_btn._ComponentsButton__last_clicked = datetime.utcnow()
+
+                    await self._handle_event(cmp_btn)
                 
                 if btn.custom_id == ComponentsButton.ID_NEXT_PAGE:
                     await inter.reply(**self._decide_kwargs(button_id=btn.custom_id))
+                    await self._contact_relay(inter.author, cmp_btn)
                 
                 elif btn.custom_id == ComponentsButton.ID_PREVIOUS_PAGE:
                     await inter.reply(**self._decide_kwargs(button_id=btn.custom_id))
+                    await self._contact_relay(inter.author, cmp_btn)
                     
                 elif btn.custom_id == ComponentsButton.ID_GO_TO_FIRST_PAGE:
                     self._pc.index = 0
                     await inter.reply(**self._decide_kwargs(button_id=btn.custom_id))
+                    await self._contact_relay(inter.author, cmp_btn)
 
                 elif btn.custom_id == ComponentsButton.ID_GO_TO_LAST_PAGE:
                     self._pc.index = self._pc.total_pages
                     await inter.reply(**self._decide_kwargs(button_id=btn.custom_id))
+                    await self._contact_relay(inter.author, cmp_btn)
                     
                 elif btn.custom_id == ComponentsButton.ID_GO_TO_PAGE:
                     await inter.reply(f'{self._ctx.author.name}, what page what you like to go to?', type=ResponseType.ChannelMessageWithSource)
@@ -541,12 +575,14 @@ class ButtonsMenu:
                                         del kwargs[key]
                             else:
                                 await self._msg.edit(**kwargs)
+                                await self._contact_relay(inter.author, cmp_btn)
 
                                 if self.delete_interactions:
                                     await user_response.delete()
                                     await inter.delete()
                     
                 elif btn.custom_id == ComponentsButton.ID_END_SESSION:
+                    await self._contact_relay(inter.author, cmp_btn)
                     await self.stop(delete_menu_message=True)
                 
                 else:
@@ -576,6 +612,7 @@ class ButtonsMenu:
                             )
                             raise ButtonsMenuException(call_failed_error_msg)
                         else:
+                            await self._contact_relay(inter.author, cmp_btn)
                             if cmp_btn.followup:
                                 # if this executes, the user doesn't want to respond with a message, only with the caller function (already called ^)
                                 if all((cmp_btn.followup.content is None, cmp_btn.followup.embed is None, cmp_btn.followup.file is None)):
@@ -611,6 +648,17 @@ class ButtonsMenu:
                         
                         followup_kwargs['type'] = ResponseType.ChannelMessageWithSource
                         await inter.reply(**followup_kwargs)
+                        await self._contact_relay(inter.author, cmp_btn)
+                    
+                    elif btn.custom_id.startswith(ComponentsButton.ID_CUSTOM_EMBED):
+                        if self._menu_type != ButtonsMenu.TypeEmbed:
+                            raise ButtonsMenuException('Buttons with custom_id ComponentsButton.ID_CUSTOM_EMBED can only be used when the menu_type is ButtonsMenu.TypeEmbed')
+                        else:
+                            if cmp_btn.followup is None or cmp_btn.followup.embed is None:
+                                raise ButtonsMenuException('ComponentsButton custom_id was set as ComponentsButton.ID_CUSTOM_EMBED but the "followup" kwargs for that ComponentsButton was not set or the "embed" kwarg for the followup was not set')
+                            
+                            await inter.reply(embed=cmp_btn.followup.embed, type=ResponseType.UpdateMessage)
+                            await self._contact_relay(inter.author, cmp_btn)
                     
                     else:
                         # this shouldnt execute because of :meth:`_button_add_check`, but just in case i missed something, raise the appropriate error
@@ -634,6 +682,83 @@ class ButtonsMenu:
         for i in range(0, len(list_), n):
             yield list_[i:i + n]
     
+    async def _contact_relay(self, member: discord.Member, button: ComponentsButton):
+        """Dispatch the information to the relay function if a relay has been set
+
+            .. added:: v2.0.1
+        """
+        if self._relay_function:
+            RelayPayload = collections.namedtuple('RelayPayload', ['member', 'button'])
+            relay = RelayPayload(member=member, button=button)
+            try:
+                if asyncio.iscoroutinefunction(self._relay_function):
+                    await self._relay_function(relay)
+                else:
+                    self._relay_function(relay)
+            except TypeError:
+                raise ButtonsMenuException('When setting a relay, the relay function must have exactly one positional argument')
+    
+    def set_relay(self, func: object):
+        """Set a function to be called with a given set of information when a button is clicked on the menu. The information passed is `RelayPayload`, a named tuple object. The
+        named tuple contains the following attributes:
+
+        - `member`: The :class:`discord.Member` object of the member who clicked the button. Could be :class:`discord.User` if the menu button was clicked in a direct message
+        - `button`: The :class:`ComponentsButton` object of the button that was clicked
+
+        Parameters
+        ---------
+        func: Callable[[:class:`NamedTuple`], :class:`None`]
+            The function should only contain a single positional argument. Discord.py command functions (`@bot.command()`) not supported
+        
+        Raises
+        ------
+        - `IncorrectType`: The argument provided was not callable
+        
+            .. added:: v2.0.1
+        """
+        if callable(func):
+            self._relay_function = func
+        else:
+            raise IncorrectType('When setting the relay, argument "func" must be callable')
+    
+    def remove_relay(self):
+        """Remove the relay that's been set
+
+            .. added:: v2.0.1
+        """
+        self._relay_function = None
+    
+    def _remove_director(self, page: Union[discord.Embed, str]):
+        """Removes the page director contents from the page
+        
+            .. added:: v2.0.1
+        """
+        style = self.style
+        if style is None:
+            style = 'Page $/&'
+        
+        escaped_style = re.escape(style)
+        STYLE_PATTERN = escaped_style.replace(r'\$', r'\d{1,}').replace(r'\&', r'\d{1,}')
+        STYLE_STR_PATTERN = escaped_style.replace(r'\$', r'\d{1,}').replace(r'\&', r'(\d{1,}.*)')
+        
+        if self.show_page_director:
+            if isinstance(page, discord.Embed):
+                if page.footer.text:
+                    DIRECTOR_PATTERN = STYLE_PATTERN + r':? '
+                    if re.search(DIRECTOR_PATTERN, page.footer.text):
+                        page.set_footer(text=re.sub(DIRECTOR_PATTERN, '', page.footer.text), icon_url=page.footer.icon_url)
+
+            elif isinstance(page, str):
+                if re.search(STYLE_STR_PATTERN, page):
+                    return re.sub(STYLE_STR_PATTERN, '', page).rstrip('\n')
+                else:
+                    return page
+
+            else:
+                raise TypeError(f'_remove_director parameter "page" expected discord.Embed or str, got {page.__class__.__name__}')
+        else:
+            return page
+    
     async def update(self, new_pages: Union[List[Union[discord.Embed, str]], None], new_buttons: Union[List[ComponentsButton], None]):
         """|coro| When the menu is running, update the pages or buttons 
 
@@ -652,6 +777,11 @@ class ButtonsMenu:
         - `TooManyButtons`: There are already 25 buttons on the menu
         - `IncorrectType`: The values in :param:`new_pages` did not match the :class:`ButtonsMenu` menu_type. An attempt to use this method when the menu_type is `ButtonsMenu.TypeEmbedDynamic` which is not allowed. Or
         all :param:`new_buttons` values were not of type :class:`ComponentsButton`
+        
+            .. changes::
+                v2.0.1
+                    Add handling for the removal of the page director
+                    Various improvements (see changelog)
         """
         if self._is_running:
             # ----------------------- CHECKS -----------------------
@@ -676,20 +806,26 @@ class ButtonsMenu:
             # ----------------------- END CHECKS -----------------------
 
             if new_pages is not None:
-                self.__pages = new_pages
-                self._pc = _PageController(new_pages)
                 if self._menu_type == ButtonsMenu.TypeEmbed:
-                    # before the refresh of the director, clear all footer information first if any. if new_pages also contains pages from the old pages, director
-                    # information will stack. Also just to clear out any text that should be reformatted to fit the page director format. This also fixes the bug where
-                    # if a menu was updated multiple times in a single session, the first click would be off by 1. it catches up after the 2nd click, but this prevents
-                    # it from happening in the first place (probably because of the director? not sure though)
-                    for embed_page in new_pages:
-                        if embed_page.footer:
-                            embed_page.set_footer(text=discord.Embed.Empty, icon_url=discord.Embed.Empty)
-
+                    for new_embed_page in new_pages:
+                        self._remove_director(new_embed_page)
+                    
+                    self.__pages = new_pages.copy()
+                    self._pc = _PageController(new_pages)
                     self._refresh_page_director_info(ButtonsMenu.TypeEmbed, self.__pages)
                 else:
+                    removed_director_info = []
+                    for new_str_page in new_pages.copy():
+                        removed_director_info.append(self._remove_director(new_str_page))
+                    
+                    self.__pages = removed_director_info.copy()
+                    self._pc = _PageController(self.__pages)
                     self._refresh_page_director_info(ButtonsMenu.TypeText, self.__pages)
+            else:
+                # page controller needs to be reset because even though there are no new pages. the page index is still in the location BEFORE the update
+                # EXAMPLE: 5 page menu > click Next button  (on page 2) > update menu no new pages > click Next button (on page 3)
+                # that makes no sense and resetting the page controller fixes that issue 
+                self._pc = _PageController(self.__pages)
             
             # determine the action the user wants for new_buttons
             kwargs_to_pass = {}
@@ -702,10 +838,14 @@ class ButtonsMenu:
                     kwargs_to_pass['components'] = []
                 else:
                     for new_btn in new_buttons:
-                        # these steps are a carbon copy of :meth:`add_button`, but bypasses :dec:`ensure_not_primed`
-                        self._button_add_check(new_btn)
-                        self._maybe_unique_id(new_btn)
-                        self._row_of_buttons.append(new_btn)
+                        # this needs to be set to `True` every loop because once the decorator has been bypassed, the decorator resets that bypass back to `False`
+                        # i could set the bypass values before and after the loop, but the time it takes for new buttons to be replaced *could* be enough time for other
+                        # calls to methods that depend on :dec:`ensure_not_primed` to be executed, which is not good . insufficient, yes i know, but its better to prevent
+                        # unwanted successful calls to methods that are decorated with :dec:`ensure_not_primed`. the benefits outweigh the costs. not to mention it's
+                        # better to have this simply call :meth:`add_button()` instead of copying the contents of :meth:`add_button()` to bypass :dec:`ensure_not_primed`
+                        self._bypass_primed = True
+                        
+                        self.add_button(new_btn)
                     else:
                         kwargs_to_pass['components'] = self._initialize_action_row()
             
@@ -721,7 +861,7 @@ class ButtonsMenu:
             await self._msg.edit(**kwargs_to_pass)
     
     async def refresh_menu_buttons(self):
-        """|coro| When the menu is running, update the message to reflect the buttons that were removed, disabled, or added"""
+        """|coro| When the menu is running, update the message to reflect the buttons that were removed, enabled, or disabled"""
         if self._is_running:
             if self._row_of_buttons:
                 await self._msg.edit(components=self._initialize_action_row())
@@ -739,14 +879,26 @@ class ButtonsMenu:
         Raises
         ------
         - `ButtonNotFound`: The provided button was not found in the list of buttons on the menu
+        
+            .. changes::
+                v2.0.1
+                    Added reset of button.__menu (set to :class:`None`)
         """
         if button in self._row_of_buttons:
+            button._ComponentsButton__menu = None
             self._row_of_buttons.remove(button)
         else:
             raise ButtonNotFound(f'Cannot remove a button that is not registered')
     
     def remove_all_buttons(self):
-        """Remove all buttons from the menu"""
+        """Remove all buttons from the menu
+        
+            .. changes::
+                v2.0.1
+                    Added reset of button.__menu (set to :class:`None`)
+        """
+        for btn in self._row_of_buttons:
+            btn._ComponentsButton__menu = None
         self._row_of_buttons.clear()
     
     def disable_button(self, button: ComponentsButton):
@@ -812,19 +964,25 @@ class ButtonsMenu:
         self._on_timeout_details = func
     
     def _button_add_check(self, button: ComponentsButton):
-        """A set of checks to ensure the proper button is being added"""
+        """A set of checks to ensure the proper button is being added
+        
+            .. changes::
+                Replaced :meth:`_get_all_ids` with re handling
+        """
         # ensure they are using only the ComponentsButton and not ReactionMenus :class:`Button` / :class:`ButtonType`
         if isinstance(button, ComponentsButton):
 
-            # ensure the button custom_id is a valid one
-            if button.custom_id not in ComponentsButton._all_ids():
-                if button.style == ComponentsButton.style.link:
-                    pass
-                else:
+            # ensure the button custom_id is a valid one, but skip this check if its a link button because they dont have custom_ids
+            if button.style == ComponentsButton.style.link:
+                pass
+            else:
+                # NOTE: this needs to be an re search because of buttons with an ID of "[ID]_[unique ID]"
+                if not re.search(ComponentsButton._RE_IDs, button.custom_id):
                     raise ButtonsMenuException(f'ComponentsButton custom_id {button.custom_id!r} was not recognized')
 
-            # ensure there are no duplicate custom_ids, excluding ComponentsButton.ID_CALLER and ComponentsButton.ID_SEND_MESSAGE
-            active_button_ids: List[str] = [btn.custom_id for btn in self._row_of_buttons if btn.custom_id not in (ComponentsButton.ID_CALLER, ComponentsButton.ID_SEND_MESSAGE)]
+            # ensure there are no duplicate custom_ids for the base navigation buttons
+            # NOTE: there's no need to have a check for buttons that are not navigation buttons because they have a unique ID and duplicates of those are allowed
+            active_button_ids: List[str] = [btn.custom_id for btn in self._row_of_buttons]
             if button.custom_id in active_button_ids:
                 name = ComponentsButton._get_id_name_from_id(button.custom_id)
                 raise ButtonsMenuException(f'A ComponentsButton with custom_id {name!r} has already been added')
@@ -836,8 +994,13 @@ class ButtonsMenu:
             raise IncorrectType(f'When adding a button to the ButtonsMenu, the button type must be ComponentsButton, got {button.__class__.__name__}')
     
     def _maybe_unique_id(self, button: ComponentsButton):
-        """Create a unique ID if the custom_id is ComponentsButton.ID_SEND_MESSAGE or ComponentsButton.ID_CALLER"""
-        if button.custom_id in (ComponentsButton.ID_CALLER, ComponentsButton.ID_SEND_MESSAGE):
+        """Create a unique ID if the custom_id is ComponentsButton.ID_SEND_MESSAGE, ComponentsButton.ID_CALLER, or ComponentsButton.ID_CUSTOM_EMBED
+        
+            .. changes::
+                v2.0.1
+                    Added handling for :attr:`ComponentsButton.ID_CUSTOM_EMBED`
+        """
+        if button.custom_id in (ComponentsButton.ID_CALLER, ComponentsButton.ID_SEND_MESSAGE, ComponentsButton.ID_CUSTOM_EMBED):
             button.custom_id = f'{button.custom_id}_{id(button)}'
     
     @ensure_not_primed
@@ -855,9 +1018,15 @@ class ButtonsMenu:
         - `ButtonsMenuException`: The custom_id for the button was not recognized. A button with that custom_id has already been added
         - `TooManyButtons`: There are already 25 buttons on the menu
         - `IncorrectType`: Parameter :param:`button` was not of type :class:`ComponentsButton`
+        
+            .. changes::
+                v2.0.1
+                    Added instantiation of self for :class:`ComponentsButton` attr `__menu`
         """
         self._button_add_check(button)
         self._maybe_unique_id(button)
+
+        button._ComponentsButton__menu = self
         self._row_of_buttons.append(button)
     
     def get_button(self, identity: str, *, search_by: str='label') -> Union[ComponentsButton, List[ComponentsButton], None]:
@@ -1156,6 +1325,10 @@ class ButtonsMenu:
         - `ButtonsMenuException`: The :class:`ButtonsMenu` menu_type was not recognized or there was an issue with locating the :param:`send_to` channel if set
         - `DescriptionOversized`: When using a menu_type of `ButtonsMenu.TypeEmbedDynamic`, the embed description was over discords size limit
         - `IncorrectType`: Parameter :param:`send_to` was not :class:`str`, :class:`int`, or :class:`discord.TextChannel`
+        
+            .. changes::
+                v2.0.1
+                    Added handling for buttons with custom_id ComponentsButton.ID_CUSTOM_EMBED
         """
         # ------------------------------- CHECKS -------------------------------
 
@@ -1164,9 +1337,7 @@ class ButtonsMenu:
         if 'components' not in send_info.kwonlyargs:
             raise MissingSetting('The "components" kwarg is missing from the .send() method. Did you forget to initialize the menu first using static method ButtonsMenu.initialize(...)?')
 
-        # ensure at least 1 page exists before starting the menu
-        if self._menu_type in (ButtonsMenu.TypeEmbed, ButtonsMenu.TypeText) and not self.__pages:
-            raise NoPages("You cannot start a ButtonsMenu when you haven't added any pages")
+        # NOTE: each at least 1 page check is done in it's own if statement to avoid clashing between pages and custom embeds
         
         # NOTE: at least 1 page check for add_row is done in "(dynamic menu)"
         
@@ -1183,13 +1354,60 @@ class ButtonsMenu:
         # add page (normal menu)
         if self._menu_type == ButtonsMenu.TypeEmbed:
             self._refresh_page_director_info(ButtonsMenu.TypeEmbed, self.__pages)
-            self._msg = await self._handle_send_to(send_to).send(embed=self.__pages[0], components=self._initialize_action_row()) # allowed_mentions not needed in embeds
-        
+
+            base_nav_btns_ids = (ComponentsButton.ID_PREVIOUS_PAGE, ComponentsButton.ID_NEXT_PAGE, ComponentsButton.ID_GO_TO_FIRST_PAGE, ComponentsButton.ID_GO_TO_LAST_PAGE, ComponentsButton.ID_GO_TO_PAGE)
+            navigation_btns = [btn for btn in self._row_of_buttons if btn.custom_id in base_nav_btns_ids]
+
+            # an re search is required here because buttons with ID_CUSTOM_EMBED dont have a normal ID, the ID is "8_[unique ID]"
+            custom_embed_btns = [btn for btn in self._row_of_buttons if btn.style != ButtonStyle.link and re.search(r'8_\d+', btn.custom_id)]
+
+            if all([not self.__pages, not custom_embed_btns]):
+                raise NoPages("You cannot start a ButtonsMenu when you haven't added any pages")
+
+            # normal pages, no custom embeds
+            if self.__pages and not custom_embed_btns:
+                self._msg = await self._handle_send_to(send_to).send(embed=self.__pages[0], components=self._initialize_action_row()) # allowed_mentions not needed in embeds
+            
+            # only custom embeds
+            elif not self.__pages and custom_embed_btns:
+                # since there are only custom embeds, there is no need for base navigation buttons, so remove them if any
+                for nav_btn in navigation_btns:
+                    if nav_btn in self._row_of_buttons:
+                        self._row_of_buttons.remove(nav_btn)
+                
+                # ensure all custom embed buttons have the proper values set
+                for custom_btn in custom_embed_btns:
+                    if custom_btn.followup is None or custom_btn.followup.embed is None:
+                        raise ButtonsMenuException('ComponentsButton custom_id was set as ComponentsButton.ID_CUSTOM_EMBED but the "followup" kwargs for that ComponentsButton was not set or the "embed" kwarg for the followup was not set')
+                
+                # since there are only custom embeds, self.__pages is still set to :class:`None`, so set the embed in `.send()` to the first custom embed in the list
+                self._msg = await self._handle_send_to(send_to).send(embed=custom_embed_btns[0].followup.embed, components=self._initialize_action_row())
+            
+            # normal pages and custom embeds
+            else:
+                # since there are custom embeds, ensure there is at least one base navigation button so they can switch between the normal pages and custom embeds
+                if not navigation_btns:
+                    error_msg = inspect.cleandoc(
+                        """
+                        Since you've added pages and custom embeds, there needs to be at least one base navigation button. Without one, there's no way to go back to the normal pages in the menu if a custom embed button is clicked.
+                        The available base navigation buttons are buttons with the custom_id:
+
+                        - ComponentsButton.ID_PREVIOUS_PAGE
+                        - ComponentsButton.ID_NEXT_PAGE
+                        - ComponentsButton.ID_GO_TO_FIRST_PAGE
+                        - ComponentsButton.ID_GO_TO_LAST_PAGE
+                        - ComponentsButton.ID_GO_TO_PAGE
+                        """
+                    )
+                    raise ButtonsMenuException(error_msg)
+                else:
+                    self._msg = await self._handle_send_to(send_to).send(embed=self.__pages[0], components=self._initialize_action_row()) # allowed_mentions not needed in embeds
+
         # add row (dynamic menu)
         elif self._menu_type == ButtonsMenu.TypeEmbedDynamic:
             for data_clump in self._chunks(self._dynamic_data_builder, self.__rows_requested):
                 joined_data = '\n'.join(data_clump)
-                if len(joined_data) <= 2000:
+                if len(joined_data) <= 4096:
                     possible_block = f"```{self.wrap_in_codeblock}\n{joined_data}```"
                     embed = discord.Embed() if self.custom_embed is None else self.custom_embed.copy()
                     embed.description = joined_data if not self.wrap_in_codeblock else possible_block
@@ -1216,6 +1434,9 @@ class ButtonsMenu:
         
         # add page (text menu)
         else:
+            if not self.__pages:
+                raise NoPages("You cannot start a ButtonsMenu when you haven't added any pages")
+            
             self._refresh_page_director_info(ButtonsMenu.TypeText, self.__pages)
             self._msg = await self._handle_send_to(send_to).send(content=self.__pages[0], components=self._initialize_action_row(), allowed_mentions=self.allowed_mentions)
         
