@@ -25,10 +25,9 @@ DEALINGS IN THE SOFTWARE.
 import asyncio
 import collections
 import itertools
-from enum import Enum, auto
 from typing import Deque, List, Union
 
-from discord import Embed, Member, Role, TextChannel
+from discord import Embed, Role, TextChannel
 from discord.ext.commands import Context
 
 from . import abc
@@ -131,10 +130,12 @@ class ReactionMenu(abc.Menu):
 				This class now inherits from :abc:`Menu`
 				
 				A sizeable amount of methods and properties were moved from here to abc.py to support :class:`TextMenu`
-            v1.1.0
+            v2.0.0
                 Added initialization of :attr:`_menu_owner` to the `__init__` instead of the execute session method, etc.
 				Added :attr:_on_timeout_details
 				Added :attr:_menu_timed_out
+			v2.0.1
+				Added :attr:`_bypass_primed`
 
 	"""
 	STATIC = 0
@@ -162,6 +163,8 @@ class ReactionMenu(abc.Menu):
 		self._on_timeout_details: 'function' = None
 		self._menu_timed_out = False
 
+		self._bypass_primed = False
+
 		# auto-pagination
 		self._menu_owner = ctx.author
 		self._auto_paginator = False
@@ -486,12 +489,12 @@ class ReactionMenu(abc.Menu):
 		------
 		- `MenuSettingsMismatch`: Tried to use method on a dynamic menu
 		- `MenuAlreadyRunning`: Attempted to call method after the menu has already started
-		- `DescriptionOversized`: Description length is over discords character limit
+		
+			.. changes::
+				v2.0.1
+					Removed embed description length check, :exc:`DescriptionOversized` was made for dynamic menus, not individual checks
 		"""
-		if len(embed.description) <= 2000:
-			self._static_completed_pages.append(embed)
-		else:
-			raise DescriptionOversized('When adding a page, your embed description was over the size limit allowed by Discord. Reduce the amount of text in your embed description')
+		self._static_completed_pages.append(embed)
 
 	@ensure_not_primed
 	def add_button(self, button: Button): 
@@ -690,7 +693,7 @@ class ReactionMenu(abc.Menu):
 					- Instead of calling str() everytime on every button emoji check, just store it in a variable to access and check later
 					- Moved to ABC
 					- Fixed issue associated with `ButtonType.GO_TO_PAGE` and kwarg `send_to` in :meth:`ReactionMenu.start`
-				v1.1.0
+				v2.0.0
 					Removed initialization of :attr:`ReactionMenu._menu_owner`. Makes more sense to set it in the `__init__`
 		"""
 		while self._is_running:
@@ -869,7 +872,7 @@ class ReactionMenu(abc.Menu):
 					- Removed [else] from ReactionMenu.STATIC/DYNAMIC check
 					- Moved #[core menu initialization] from both STATIC and DYNAMIC if checks to only one at the bottom. Having both was redundant because regardless of configuration both have the same #[core menu initialization]
 					- Now raises :exc:`NoButtons` (from decorator `menu_verification`)
-				v1.1.0
+				v2.0.0
 					Added handling for per limit type
 		"""
 		# check if the menu is limited
@@ -959,7 +962,7 @@ class ReactionMenu(abc.Menu):
 			for data_clump in self._chunks(self._dynamic_data_builder, self._rows_requested):
 				embed = self._maybe_custom_embed()
 				joined_data = '\n'.join(data_clump)
-				if len(joined_data) <= 2000:
+				if len(joined_data) <= 4096:
 					possible_block = f"```{self._wrap_in_codeblock}\n{joined_data}```"			
 					embed.description = joined_data if not self._wrap_in_codeblock else possible_block
 					self._dynamic_completed_pages.append(embed)
