@@ -25,7 +25,7 @@ DEALINGS IN THE SOFTWARE.
 import asyncio
 from functools import wraps
 
-from .errors import MenuSettingsMismatch, MenuAlreadyRunning, ReactionMenuException, NoButtons
+from .errors import MenuSettingsMismatch, MenuAlreadyRunning, NoButtons
 
 __all__ = ('menu_verification', 'dynamic_only', 'static_only', 'ensure_not_primed')
 
@@ -88,14 +88,18 @@ def ensure_not_primed(func):
     """Check to make sure certain methods cannot be ran once the menu has been fully started
     
         .. changes::
-            v1.1.0
+            v2.0.0
                 Added inst name check so this decorator is compatible with :class:`ButtonsMenu`
+            v2.0.1
+                Added handling for `inst._bypass_primed`
     """
     if asyncio.iscoroutinefunction(func):
         @wraps(func)
         async def wrapper(*args, **kwargs):
             inst = args[0]
-            if not inst._is_running:
+            if not inst._is_running or inst._bypass_primed:
+                if inst._bypass_primed:
+                    inst._bypass_primed = False
                 return await func(*args, **kwargs)
             else:
                 raise MenuAlreadyRunning(f'You cannot use method "{func.__name__}" after the menu has started. Menu name: {inst._name}')
@@ -104,7 +108,9 @@ def ensure_not_primed(func):
         @wraps(func)
         def wrapper(*args, **kwargs):
             inst = args[0]
-            if not inst._is_running:
+            if not inst._is_running or inst._bypass_primed:
+                if inst._bypass_primed:
+                    inst._bypass_primed = False
                 func(*args, **kwargs)
             else:
                 if inst.__class__.__name__ == 'ButtonsMenu':
