@@ -23,19 +23,18 @@ DEALINGS IN THE SOFTWARE.
 """
 
 import asyncio
-import collections
 import inspect
 import itertools
 import re
 from typing import List, Union
 
-from discord import AllowedMentions, Member, Role, TextChannel
+from discord import AllowedMentions, Role, TextChannel
 from discord.ext.commands import Context
 
 from . import abc
 from .buttons import Button, ButtonType
 from .decorators import ensure_not_primed, menu_verification
-from .errors import DuplicateButton, IncorrectType, MenuAlreadyRunning, MissingSetting, ReactionMenuException, TooManyButtons
+from .errors import DuplicateButton, IncorrectType, MissingSetting, ReactionMenuException, TooManyButtons
 
 
 class TextMenu(abc.Menu):
@@ -91,10 +90,12 @@ class TextMenu(abc.Menu):
         .. added:: v1.0.9
 
         .. changes ::
-            v1.1.0
+            v2.0.0
                 Added initialization of :attr:`_menu_owner` to the `__init__` instead of the execute session method, etc.
                 Added :attr:_on_timeout_details
                 Added :attr:_menu_timed_out
+            v2.0.1
+				Added :attr:`_bypass_primed`
     """
     _active_sessions: List['TextMenu'] = []
 
@@ -116,6 +117,8 @@ class TextMenu(abc.Menu):
         self._relay_function = None
         self._on_timeout_details: 'function' = None
         self._menu_timed_out = False
+
+        self._bypass_primed = False
         
         # auto-pagination
         self._menu_owner = ctx.author
